@@ -22,7 +22,7 @@ import win32gui
 from win32com.shell import shell, shellcon
 #import Xlib.support.connect as xlib_connect
 
-api_version = '3.1.1.0'
+api_version = '3.1.2.0'
 
 try:
     from lang import *
@@ -673,7 +673,7 @@ async def check_task(config, ckey, message, websocket):
         TASK_CHECKING[ ckey+"_"+task_uid ] = True
         pass
 
-    print('check evaluating batches:', batches, current_batch, start_len)
+    #print('check evaluating batches:', batches, current_batch, start_len)
     batch_result   = []
     output_result  = ""
     error_result  = ""
@@ -743,9 +743,9 @@ async def check_task(config, ckey, message, websocket):
             output_result  = output
             error_result   = err
         pass
-    print("get batch result:", batch_result, )
-    print("output result = ", output_result)
-    print("error result = ", error_result)
+    #print("get batch result:", batch_result, )
+    #print("output result = ", output_result)
+    #print("error result = ", error_result)
 
     await websocket.send( json.dumps({
         "name"            : "check-task",
